@@ -82,16 +82,62 @@ public:
     };
     Q_ENUM(SavePageFormat)
 
+    enum DownloadInterruptReason {
+        NoReason = 0,
+        FileFailed = 1,
+        FileAccessDenied = 2,
+        FileNoSpace = 3,
+        FileNameTooLong = 5,
+        FileTooLarge = 6,
+        FileVirusInfected = 7,
+        FileTransientError = 10,
+        FileBlocked = 11,
+        FileSecurityCheckFailed = 12,
+        FileTooShort = 13,
+        FileHashMismatch = 14,
+        NetworkFailed = 20,
+        NetworkTimeout = 21,
+        NetworkDisconnected = 22,
+        NetworkServerDown = 23,
+        NetworkInvalidRequest = 24,
+        ServerFailed = 30,
+        //ServerNoRange = 31,
+        ServerBadContent = 33,
+        ServerUnauthorized = 34,
+        ServerCertProblem = 35,
+        ServerForbidden = 36,
+        ServerUnreachable = 37,
+        UserCanceled = 40,
+        //UserShutdown = 41,
+        //Crash = 50
+    };
+    Q_ENUM(DownloadInterruptReason)
+
+    enum DownloadType {
+        Attachment = 0,
+        DownloadAttribute,
+        UserRequested,
+        SavePage
+    };
+    Q_ENUM(DownloadType)
+
     Q_PROPERTY(quint32 id READ id CONSTANT FINAL)
-    Q_PROPERTY(DownloadState state READ state NOTIFY stateChanged)
+    Q_PROPERTY(DownloadState state READ state NOTIFY stateChanged FINAL)
     Q_PROPERTY(SavePageFormat savePageFormat READ savePageFormat WRITE setSavePageFormat NOTIFY savePageFormatChanged REVISION 2 FINAL)
-    Q_PROPERTY(qint64 totalBytes READ totalBytes NOTIFY totalBytesChanged)
-    Q_PROPERTY(qint64 receivedBytes READ receivedBytes NOTIFY receivedBytesChanged)
-    Q_PROPERTY(QString mimeType READ mimeType NOTIFY mimeTypeChanged REVISION 1)
-    Q_PROPERTY(QString path READ path WRITE setPath NOTIFY pathChanged)
+    Q_PROPERTY(qint64 totalBytes READ totalBytes NOTIFY totalBytesChanged FINAL)
+    Q_PROPERTY(qint64 receivedBytes READ receivedBytes NOTIFY receivedBytesChanged FINAL)
+    Q_PROPERTY(QString mimeType READ mimeType NOTIFY mimeTypeChanged REVISION 1 FINAL)
+    Q_PROPERTY(QString path READ path WRITE setPath NOTIFY pathChanged FINAL)
+    Q_PROPERTY(DownloadType type READ type NOTIFY typeChanged REVISION 3 FINAL)
+    Q_PROPERTY(DownloadInterruptReason interruptReason READ interruptReason NOTIFY interruptReasonChanged REVISION 4 FINAL)
+    Q_PROPERTY(QString interruptReasonString READ interruptReasonString NOTIFY interruptReasonChanged REVISION 4 FINAL)
+    Q_PROPERTY(bool isFinished READ isFinished NOTIFY isFinishedChanged REVISION 5 FINAL)
+    Q_PROPERTY(bool isPaused READ isPaused NOTIFY isPausedChanged REVISION 5 FINAL)
 
     Q_INVOKABLE void accept();
     Q_INVOKABLE void cancel();
+    Q_INVOKABLE void pause();
+    Q_INVOKABLE void resume();
 
     quint32 id() const;
     DownloadState state() const;
@@ -102,6 +148,11 @@ public:
     void setPath(QString path);
     SavePageFormat savePageFormat() const;
     void setSavePageFormat(SavePageFormat format);
+    DownloadType type() const;
+    DownloadInterruptReason interruptReason() const;
+    QString interruptReasonString() const;
+    bool isFinished() const;
+    bool isPaused() const;
 
 Q_SIGNALS:
     void stateChanged();
@@ -110,6 +161,10 @@ Q_SIGNALS:
     void totalBytesChanged();
     Q_REVISION(1) void mimeTypeChanged();
     void pathChanged();
+    Q_REVISION(3) void typeChanged();
+    Q_REVISION(4) void interruptReasonChanged();
+    Q_REVISION(5) void isFinishedChanged();
+    Q_REVISION(5) void isPausedChanged();
 
 private:
     QQuickWebEngineDownloadItem(QQuickWebEngineDownloadItemPrivate*, QObject *parent = 0);
